# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import marax_server_sdk
from marax_server_sdk.models.request_body_properties_reward import RequestBodyPropertiesReward  # noqa: E501
from marax_server_sdk.rest import ApiException

class TestRequestBodyPropertiesReward(unittest.TestCase):
    """RequestBodyPropertiesReward unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RequestBodyPropertiesReward
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = marax_server_sdk.models.request_body_properties_reward.RequestBodyPropertiesReward()  # noqa: E501
        if include_optional :
            return RequestBodyPropertiesReward(
                id = '0', 
                expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                timezone = 'Asia/Kolkata', 
                promocode = 'SWIGGYIT', 
                title = 'Flat Rs 100/- off', 
                body = 'Applicable on all order above', 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                type = 'monetory', 
                ui = 'scratch_card', 
                handled_by = 'marax'
            )
        else :
            return RequestBodyPropertiesReward(
        )

    def testRequestBodyPropertiesReward(self):
        """Test RequestBodyPropertiesReward"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
