# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.3.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import marax_server_sdk
from marax_server_sdk.models.response400 import Response400  # noqa: E501
from marax_server_sdk.rest import ApiException

class TestResponse400(unittest.TestCase):
    """Response400 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Response400
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = marax_server_sdk.models.response400.Response400()  # noqa: E501
        if include_optional :
            return Response400(
                status = 'error', 
                message = 'Invalid Body'
            )
        else :
            return Response400(
        )

    def testResponse400(self):
        """Test Response400"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
